####   Dreidimensionaler Plot als zweidimensionale Map ("Karte")   ################
####   Falschfarbendarstellung im PM3D-Stil
####   Multiplot-Layout
####   Plot: DF9GH
####   Nach: King-Hele, D. G., Cook, G. E.: The Even Zonal Harmonics of the Earth's
####                  Gravitational Potential, Geophysical Journal (1965) 10, S. 17


####  Interface (Ausgabe: PDF)   ##################################################
#set terminal pdfcairo enhanced linewidth 4 font 'Arial,20' size 18.4cm,18.4cm
#set output "c:/verzeichnis/Bild.7.pdf"


#####   Physikalische Konstanten   ################################################
J2 = 1.082616E-3                                            ### Jeffreys-Konstanten
J3 = -2.53881E-6
J4 = -1.65597E-6
R = 6378.163                                                          ### Erdradius
h = 400                                                             ### Hhenniveau
r = R/(R+h)


set multiplot layout 2,1 title "Anomalien des Schwerepotentials U [5]\nHhenniveau: 400 km"
              ### Mehrfach-Plot definieren                           ### hier Zeilenumbruch

#####   oberen Plot initialisieren   ###############################################
unset key                                                        ### Plotkey sperren
set view 50,60,1,1.9                                      ### Perspektive einstellen
set isosamples 2,360                                      ### 2 x-Werte, 360 y-Werte
set angle degrees                                            ### Grad statt Bogenma
set xrange [ -180 : 180 ]                                         ### Wertebereich x
set yrange [ -90 : 90 ]                                           ### Wertebereich y
set zrange [ 0.999040574 : 1.000479792 ]                          ### Wertebereich z
set cbrange [ 0.999040574 : 1.000479792 ]              ### Wertebereich Falschfarben 
set grid                                             ### x-y-Achsengitter (Gradnetz) 
set colorbox user origin 0.78,0.77 size .025,0.2           ### Farbbalken definieren
set xtics -180,60 nomirror    ### Marken x-Achse, Beginn -180, Abstand 60, einseitig
set ytics -90,30 nomirror                              ### Marken y-Achse, einseitig
set xyplane at 0.9988                                   ### x-y-Ebene bei z = 0.9988
set xlabel "Geografische Lnge []" offset 1,-1.5           ### Beschriftung x-Achse
set ylabel "Geografische Breite []" offset 0,-0.5          ### Beschriftung y-Achse
set zlabel "U" offset 9,3                                   ### Beschriftung z-Achse
set style function pm3d               ### nachfolg. Funktion in Falschfarben plotten


#####   zu plottende Funktion   ####################################################
f(x,y) = 1  -  (J2*r**2*(3*sin(y)**2-1)/2  +  J3*r**3*(5*sin(y)**3-3*sin(y))/2  +  J4*r**4*(35*sin(y)**4-30*sin(y)**2+3)/8)


#####   oberen Plot in Falschfarben plotten   ######################################
set pm3d depthorder      ### Falschfarbendarstellung, verdeckte Flchen (depthorder)
splot f(x,y), 1                                          ### "1" ist Ebene durch z=1


#####   unteren Plot nachinitialisieren   ##########################################
set view map                                 ### 3D-Plot zweidimensional projezieren
set size 0.85,0.50                        ### Seitenverhltnis x:y des unteren Plots 
set cblabel "Schwerepotential U"                         ### Beschriftung Farbbalken
set colorbox default                                  ### Standard-Farbbalken setzen
set xlabel "Geografische Lnge []" offset 0,0.5            ### Beschriftung x-Achse
set ylabel "Geografische Breite []" offset -1,0            ### Beschriftung y-Achse


#####   unteren Plot in Falschfarben plotten   #####################################
set pm3d                     ### Falschfarbendarstellung auf Grundeinstellung setzen
splot f(x,y)